@@ -19,6 +19,7 @@
                 "train_position",
                 "Stat",
                 "GeomPath",
+                "GeomPolygon",
                 "add_group",
                 "scales_transform_df",
                 "reset_scales",
@@ -42,7 +43,8 @@
                 "update_guides",
                 "zeroGrob",
                 "el_def",
-                "digest.ggplot"
+                "digest.ggplot",
+                "layer"
 ))
 
 #' \code{ggint} is a structure which holds all the required internal functions from the ggplot2 namespace, 
